! Subroutine to do power iteration to find largest real eigen value of A
! Will work only for real eigen values
! Let phi = x2
! See 226-234 ; Kincaid and Cheney, 1991
subroutine power(a,n,x,y,r,m)
integer,intent(in) :: n,m 
real,intent(in) :: a(n,n)
real,intent(inout) :: x(n),y(n),r
real :: ymag
integer :: k
do k = 1,m
  call matvec(a,x,y,n,n)
  r = y(2)/x(2)
  call vec_mag(y,n,ymag)
  x = y/ymag
  write(*,*)'r,x',r,x
enddo
return
end
subroutine matvec(a,x,y,m,n)
real,intent(in) :: a(m,n),x(n)
integer,intent(in) :: m,n
real,intent(out) :: y(n)
integer :: i,k

do i = 1,m
  y(i) = 0.0
  do k = 1,n
    y(i) = y(i) + a(i,k)*x(k)
  enddo
enddo
return
end

subroutine vec_mag(x,n,x_mag)
real,intent(in) :: x(n)
integer,intent(in) :: n
real,intent(out) :: x_mag
integer :: i
x_mag = 0.0
do i = 1,n
  x_mag = x_mag + x(i)*x(i)
enddo
x_mag = sqrt(x_mag)
return
end

program eigen_large
parameter (n=3,nit_max=28)
real :: a(n,n),x(n),y(n),r
data a/2.0,-2,-1.0,0.0,-10.0,-1.0,-1.0,0.0,4.0/
data x/-1.0,1.0,1.0/
!
call power(a,n,x,y,r,nit_max)
end program eigen_large



  
  
